@@ -1,6 +1,6 @@
 dispMUA.arDispMUAAllocation["6"] =
 {
   "6.0 for windows" : [ "aol.png" , "http://www.aol.com/" ] ,
-  "602lan suite" : [ "lansuite.png" ] ,
+  "602lan suite" : [ "software602.png" , "http://www.software602.com/" ] ,
   "6.0 sub " : [ "aol.png" , "http://www.aol.com/" ] ,
 }
