@@ -1,9 +1,10 @@
 dispMUA.arDispMUAAllocation["d"] =
 {
+  "dynamic internet messaging program" : [ "horde.png" , "http://www.horde.org/dimp/" ] ,
   "do, or do not. there is no try." : [ "mixi.png" , "http://mixi.jp/" ] ,
   "desis & sertic :: facturacion" : [ "desis.png" , "http://www.desis.cl/" ] ,
   "dodo internet webmail server" : [ "dodo.png" , "http://www.dodo.com.au/" ] ,
-  "datenkraft newsletter system" : [ "datenkraft.png" ] ,
+  "datenkraft newsletter system" : [ "datenkraft.png" , "http://www.datenkraft.com/" ] ,
   "dmc - www.dmcdeutschland.de" : [ "dmc.png" , "http://www.dmcdeutschland.de/" ] ,
   "digionline gmbh webweaver" : [ "digionline_webweaver.png" , "http://www.ww3ee.de/" ] ,
   "deutsche steuerverwaltung" : [ "elster.png" , "http://www.elster.de/" ] ,
@@ -12,60 +13,84 @@ dispMUA.arDispMUAAllocation["d"] =
   "dreamhost mailing lists" : [ "dreamhost.png" , "http://www.dreamhost.com/" ] ,
   "doubleclick clickmailer" : [ "clickmailer.png" , "http://www.clickmailer.jp/" ] ,
   "doubleclick clickm@iler" : [ "clickmailer.png" , "http://www.clickmailer.jp/" ] ,
+  "data protector express" : [ "hp_data-protector-express.png" , "http://h18006.www1.hp.com/products/software/im/biz_continuity_avail/dp/" ] ,
   "de.tivano.mail.mailer" : [ "tivano_de.png" , "http://www.tivano.de/" ] ,
+  "dial systems esponse" : [ "esponse.png" , "http://www.dialsystems.de/ESP_0.php" ] ,
+  "delaforge consulting" : [ "xds-consulting.png" , "http://www.xds-consulting.com/" ] ,
+  "datingwalk mailagent" : [ "datingwalk.png" , "http://www.datingwalk.com/" ] ,
   "domain-offensive.de" : [ "domainoffensive.png" , "http://www.domain-offensive.de/" ] ,
   "donorware sendbulk" : [ "donorware.png" ] ,
+  "debian thunderbird" : [ "thunderbird.png" , "http://www.debian.org/" ] ,
+  "date.bluesystem.ru" : [ "bluesystem_ru.png" , "http://date.bluesystem.ru/" ] ,
   "dreamhost webmail" : [ "dreamhost.png" , "http://www.dreamhost.com/" ] ,
-  "delano e-business" : [ "delano.png" ] ,
+  "delano e-business" : [ "delano.png" , "http://www.delanotech.com/" ] ,
   "dynabyte webshop" : [ "dynabyte.png" , "http://www.dyna-byte.de/" ] ,
   "dumbonet systems" : [ "dumbonet.png" ] ,
   "directemail xtra" : [ "directmailxtra.png" ] ,
+  "direct read news" : [ "drn.png" , "http://nntpjunkie.com/drn.htm" ] ,
   "draco organizer" : [ "draco.png" , "http://www.dracosoftware.pl/" ] ,
-  "divmod-quotient" : [ "divmod.png" ] ,
-  "distributed.net" : [ "distributednet.png" ] ,
+  "divmod-quotient" : [ "divmod.png" , "http://divmod.org/" ] ,
+  "distributed.net" : [ "distributed_net.png" , "http://distributed.net/" ] ,
   "daum web mailer" : [ "daum_webmail.png" ] ,
   "datenbankmailer" : [ "datenbankmailer.png" , "http://www.datenbankmailer.de/" ] ,
   "dvise by tobit" : [ "tobit_david.png" , "http://www.tobit.com/" ] ,
-  "dotnetopenmail" : [ "dotnetopenmail.png" ] ,
+  "dotnetopenmail" : [ "dotnetopenmail.png" , "http://dotnetopenmail.sourceforge.net/" ] ,
   "david by tobit" : [ "tobit_david.png" , "http://www.tobit.com/" ] ,
   "danger service" : [ "danger.png" ] ,
   "dacons mail.it" : [ "dacons_mail_it.png" , "http://www.dacons.net/fmplugins/mailit/" ] ,
-  "dundas mailer" : [ "dundas.png" ] ,
-  "domainfactory" : [ "domainfactory.png" ] ,
+  "dundas mailer" : [ "dundas.png" , "http://www.dundas.com/" ] ,
+  "domainfactory" : [ "domainfactory.png" , "http://www.df.eu/" ] ,
   "de.netlog.com" : [ "netlog_com.png" , "http://de.netlog.com/" ] ,
+  "dw mime mail" : [ "directoriowarez.png" , "http://www.directoriowarez.com/" ] ,
+  "dhd24 mailer" : [ "dhd24.png" , "http://www.dhd24.com/" ] ,
   "douhou@mail" : [ "douhou.png" , "http://www.netdeoshigoto.com/mail/" ] ,
   "directmail/" : [ "toolmaker_de.png" , "http://www.toolmaker.de/" ] ,
   "dialog-mail" : [ "dialog-mail.png" , "http://www.dialog-mail.com/" ] ,
-  "devmail.net" : [ "devmailnet.png" ] ,
+  "devmail.net" : [ "devmailnet.png" , "http://www.devmail.net/" ] ,
+  "deezer mail" : [ "deezer.png" , "http://www.deezer.com/" ] ,
   "dsa-launch" : [ "dsa_launch.png" ] ,
   "dotproject" : [ "dotproject.png" , "http://www.dotproject.net/" ] ,
+  "dmdelivery" : [ "dmdelivery.png" , "http://www.webpower.nl/wp.php/dmdelivery/" ] ,
   "discount24" : [ "discount24_de.png" , "http://www.discount24.de/" ] ,
+  "delisprint" : [ "dpd.png" , "http://delisonline.dpd.de/" ] ,
   "dti tools" : [ "dti.png" , "http://dream.jp/option/tools/" ] ,
   "dtemapper" : [ "dtemapper.png" , "http://www.desis.cl/" ] ,
-  "dreammail" : [ "dreammailer.png" ] ,
-  "desknet's" : [ "desknet.png" ] ,
+  "dreammail" : [ "dreammailer.png" , "http://www.dreammailer.de/" ] ,
+  "desknet's" : [ "desknet.png" , "http://www.desknets.com/" ] ,
   "delosmail" : [ "delosmail.png" , "http://e-delos.com/" ] ,
   "datevmail" : [ "datev.png" , "http://www.datev.de/" ] ,
-  "dada mail" : [ "dada_mail.png" ] ,
+  "dada mail" : [ "dada_mail.png" , "http://dadamailproject.com/" ] ,
   "dovenews" : [ "dovenews.png" ] ,
   "dotclear" : [ "dotclear.png" ] ,
+  "dispatch" : [ "dispatch.png" , "http://www.abacusemedia.com/section.asp?catid=388" ] ,
   "dmailweb" : [ "netwinsite.png" , "http://netwinsite.com/dmailweb/" ] ,
   "dell mfp" : [ "dell.png" , "http://www.dell.com/" ] ,
+  "delcampe" : [ "delcampe.png" , "http://delcampe.net/" ] ,
+  "deepmail" : [ "deepsoft.png" , "http://www.deepsoft.co.jp/html/deepmail01.html" ] ,
+  "dotname" : [ "dotname.png" , "http://www.gnr.name/" ] ,
+  "domisys" : [ "domisys.png" , "http://www.domisys.com/" ] ,
   "dls.net" : [ "dls_net.png" , "http://www.dls.net/" ] ,
   "discuz!" : [ "discuz.png" , "http://www.discuz.com/" ] ,
   "di-php4" : [ "di_com_pl.png" , "http://www.di.com.pl/" ] ,
   "deskpro" : [ "deskpro.png" , "http://www.deskpro.com/" ] ,
   "desknow" : [ "desknow.png" ] ,
-  "denshin" : [ "denshin.png" ] ,
-  "dyndns" : [ "dyndns.png" ] ,
-  "dtmail" : [ "dtmail.png" ] ,
+  "depo.hu" : [ "depo_hu.png" , "http://www.depo.hu/" ] ,
+  "denshin" : [ "denshin.png" , "http://www.denshin8.jp/" ] ,
+  "dyndns" : [ "dyndns.png" , "http://www.dyndns.com/" ] ,
+  "dwmail" : [ "dwmail.png" , "http://www.dwmail.net/" ] ,
+  "dtmail" : [ "dtmail.png" , "http://www.sun.com/software/solaris/cde/" ] ,
   "dspwin" : [ "dspwin.png" , "http://www.dspwin.de/" ] ,
-  "drupal" : [ "drupal.png" ] ,
+  "drupal" : [ "drupal.png" , "http://drupal.org/" ] ,
   "dr.web" : [ "drweb.png" , "http://www.drweb-online.com/" ] ,
+  "dopost" : [ "dolist.png" , "http://software.dolist.net/" ] ,
+  "dolist" : [ "dolist.png" , "http://software.dolist.net/" ] ,
   "discus" : [ "labrate.png" , "http://www.labrate.ru/discus/" ] ,
-  "direto" : [ "direto.png" ] ,
-  "dcmail" : [ "dcmail.png" , "http://www.dcmail.net/" ] ,
-  "datula" : [ "datula.png" ] ,
-  "danaos" : [ "danaos.png" ] ,
+  "direto" : [ "direto.png" , "http://www.direto.org/" ] ,
+  "denbun" : [ "denbun.png" , "http://www.denbun.com/" ] ,
+  "dcmail" : [ "dcmail.png" , "http://www.mediaten.com/" ] ,
+  "datula" : [ "datula.png" , "http://www.onsystems.co.jp/" ] ,
+  "danaos" : [ "danaos.png" , "http://www.danaos.com/" ] ,
   "dmail" : [ "netwinsite_dmail.png" , "http://netwinsite.com/dmail_first.htm" ] ,
+  "dmu " : [ "waltrs_com.png" , "http://www.waltrs.com/" ] ,
+  "dbox" : [ "dbox.png" , "http://www.dbox.handshake.de/" ] ,
 }
