@@ -1,24 +1,30 @@
 dispMUA.arDispMUAAllocation["h"] =
 {
   "html newsletter (www.cybershop.de)" : [ "cybershop_de.png" , "http://www.cybershop.de/" ] ,
-  "http://www.proautoresponder.com/" : [ "proautoresponder_com.png" , "http://www.proautoresponder.com/" ] ,
   "http://www.courier-mta.org/cone/" : [ "cone.png" , "http://www.courier-mta.org/cone/" ] ,
   "http://www.umailcampaign.com" : [ "umailcampaign_com.png" , "http://www.umailcampaign.com/" ] ,
   "http://newsgroup.virgilio.it" : [ "virgilio.png" , "http://newsgroup.virgilio.it/" ] ,
-  "horde application framework" : [ "horde.png" ] ,
+  "horde application framework" : [ "horde.png" , "http://www.horde.org/horde/" ] ,
   "http://www.phpclasses.org" : [ "phpclasses.png" , "http://www.phpclasses.org/" ] ,
   "http://www.postblitz.net" : [ "postblitz.png" , "http://www.postblitz.net/" ] ,
   "hostpoint generic mailer" : [ "hostpoint.png" , "http://www.hostpoint.ch/" ] ,
   "http://www.spamcop.net/" : [ "spamcop.png" , "http://www.spamcop.net/" ] ,
   "http://www.letterit.de" : [ "letterit.png" , "http://www.letterit.de/" ] ,
   "http://nntp.angelsk.ru" : [ "nntp_angelsk_ru.png" , "http://nntp.angelsk.ru/" ] ,
+  "http://anonymouse.org/" : [ "anonymouse.png" , "http://anonymouse.org/" ] ,
+  "http://www.iradio.be" : [ "iradio_be.png" , "http://www.iradio.be/" ] ,
   "http://www.9cays.com" : [ "9cays_com.png" , "http://www.9cays.com/" ] ,
   "http://niusy.onet.pl" : [ "onet_pl.png" , "http://niusy.onet.pl/" ] ,
+  "hitachi-ms gracemail" : [ "gracemail.png" , "http://www.hitachi-ad.co.jp/gracemail/" ] ,
+  "hitachi-ad gracemail" : [ "gracemail.png" , "http://www.hitachi-ad.co.jp/gracemail/" ] ,
   "http://sub.4free.pl" : [ "4free_pl.png" , "http://www.4free.pl/" ] ,
-  "hula modweb module" : [ "hula.png" ] ,
+  "hula modweb module" : [ "hula.png" , "http://www.hula-project.org/" ] ,
   "http://www.payu.pl" : [ "payu_pl.png" , "http://www.payu.pl/" ] ,
+  "hde customers care" : [ "hde.png" , "http://www.hde.co.jp/cc/" ] ,
+  "http://0180.info/" : [ "teltarif.png" , "http://www.tk-anbieter.de/0180/" ] ,
   "helpdesk webmail" : [ "islandnet.png" , "http://helpdesk.islandnet.com/" ] ,
   "heise emailcheck" : [ "heise_security.png" , "http://www.heise.de/security/dienste/emailcheck/" ] ,
+  "habrahabr mailer" : [ "habrahabr_ru.png" , "http://habrahabr.ru/" ] ,
   "highwire mailer" : [ "highwire_mailer.png" ] ,
   "html mime mail" : [ "phpguru_org.png" , "http://www.phpguru.org/" ] ,
   "highpoint-smtp" : [ "highpoint.png" , "http://www.highpoint-tech.com/" ] ,
@@ -27,17 +33,18 @@ dispMUA.arDispMUAAllocation["h"] =
   "hifi-forum.de" : [ "hifi-forum_de.png" , "http://www.hifi-forum.de/" ] ,
   "htmlmimemail" : [ "phpguru_org.png" , "http://www.phpguru.org/" ] ,
   "holidaycheck" : [ "holidaycheck.png" , "http://www.holidaycheck.de/" ] ,
-  "hidemarumail" : [ "hidemaru.png" ] ,
+  "hidemarumail" : [ "hidemaru.png" , "http://hide.maruo.co.jp/software/hidemaru.html" ] ,
   "hhde webmail" : [ "hhde.png" ] ,
   "hp openview" : [ "hp_openview.png" , "http://www.openview.hp.com/" ] ,
-  "hogwasher" : [ "hogwasher.png" ] ,
-  "hastymail" : [ "hastymail.png" ] ,
+  "heisetreff" : [ "heisetreff.png" , "http://www.heisetreff.de/" ] ,
+  "hogwasher" : [ "hogwasher.png" , "http://www.asar.com/hogwasher.html" ] ,
+  "hastymail" : [ "hastymail.png" , "http://www.hastymail.org/" ] ,
   "hotel.de" : [ "hotel_de.png" , "http://www.hotel.de/" ] ,
   "helpspot" : [ "helpspot.png" , "http://www.userscape.com/" ] ,
   "home.ro" : [ "home_ro.png" , "http://www.home.ro/" ] ,
   "home.pl" : [ "home_pl.png" , "http://home.pl/" ] ,
-  "hamster" : [ "hamster.png" ] ,
+  "hamster" : [ "hamster.png" , "http://www.elbiah.de/hamster/" ] ,
   "hot.ee" : [ "elion_hot.png" , "http://portal.hot.ee/" ] ,
   "h+bedv" : [ "avira.png" , "http://www.free-av.de/" ] ,
-  "hafas" : [ "db.png" , "http://bahn.hafas.de/" ] ,
+  "hafas" : [ "hafas.png" , "http://www.hafas.de/hafas/ref.shtml" ] ,
 }
