@@ -8,27 +8,35 @@ dispMUA.arDispMUAAllocation["l"] =
   "lotus notes release 5" : [ "lotus_notes5.png" , "http://www.ibm.com/software/lotus/" ] ,
   "lotus notes build v8" : [ "lotus_notes8.png" , "http://www.ibm.com/software/lotus/" ] ,
   "lotus notes build v7" : [ "lotus_notes7.png" , "http://www.ibm.com/software/lotus/" ] ,
-  "lursoft mail engine" : [ "lursoft.png" ] ,
+  "lursoft mail engine" : [ "lursoft.png" , "http://www.lursoft.lv/" ] ,
   "linuxquestions.org" : [ "linuxquestions_org.png" , "http://www.linuxquestions.org/" ] ,
-  "lasso professional" : [ "lasso.png" ] ,
-  "lycos web mailer" : [ "lycos_mail.png" ] ,
+  "lasso professional" : [ "lasso.png" , "http://www.lassosoft.com/products/LassoPro/" ] ,
+  "lycos web mailer" : [ "lycos.png" , "http://mail.lycos.com/" ] ,
+  "le courrielleur" : [ "courrielleur.png" , "http://www.courrielleur.com/" ] ,
   "lussumo mailer" : [ "lussumo.png" , "http://lussumo.com/" ] ,
-  "loadmail smtp" : [ "loadmail.png" ] ,
-  "l-soft hdmail" : [ "hdmail.png" , "http://www.lsoft.com/PRODUCTS/hdmail.asp" ] ,
+  "loadmail smtp" : [ "loadmail.png" , "http://www.load.com/loadmail/" ] ,
+  "lcg profimail" : [ "lcg-profimail.png" , "http://www.lonelycatgames.com/?app=profimail" ] ,
+  "l-soft hdmail" : [ "lsoft-hdmail.png" , "http://www.lsoft.se/products/hdmail.asp" ] ,
   "lotus domino" : [ "lotus_domino6.png" , "http://www.ibm.com/software/lotus/" ] ,
   "lotus notes" : [ "lotus_notes.png" , "http://www.ibm.com/software/lotus/" ] ,
-  "libwww-perl" : [ "libwww-perl.png" , "http://linpro.no/lwp/" ] ,
-  "laszlo mail" : [ "laszlomail.png" ] ,
-  "lycosmail" : [ "lycos.png" ] ,
+  "libwww-perl" : [ "perl.png" , "http://search.cpan.org/dist/libwww-perl/" ] ,
+  "laszlo mail" : [ "laszlomail.png" , "http://www.laszlomail.com/" ] ,
+  "lycosmail" : [ "lycos.png" , "http://mail.lycos.com/" ] ,
   "lq mailer" : [ "linuxquestions_org.png" , "http://www.linuxquestions.org/" ] ,
   "logicmail" : [ "logicmail.png" , "http://www.logicprobe.org/proj/logicmail" ] ,
-  "log_mail" : [ "pear.png" ] ,
-  "locamail" : [ "locamail.png" ] ,
-  "listserv" : [ "listserv.png" ] ,
+  "listmerge" : [ "listmerge.png" , "http://www.dtp-aus.com/cgiscript/lmrgscpt.shtml" ] ,
+  "lfsmailer" : [ "lfs_net.png" , "http://www.lfs.net/" ] ,
+  "lush.com" : [ "lush.png" , "http://www.lush.com/" ] ,
+  "log_mail" : [ "pear.png" , "http://pear.php.net/package/Log/docs/latest/Log/Log_mail.html" ] ,
+  "locamail" : [ "locamail.png" , "http://www.locamail.com.br/" ] ,
+  "listserv" : [ "lsoft-listserv.png" , "http://www.lsoft.se/products/listserv.asp" ] ,
   "listmail" : [ "listmail.png" , "http://www.listmailpro.com/" ] ,
+  "leafnode" : [ "leafnode.png" , "http://leafnode.sourceforge.net/" ] ,
   "lobocom" : [ "lobocom.png" , "http://webmail.lobocom.es/" ] ,
-  "listrak" : [ "listrak.png" ] ,
+  "listrak" : [ "listrak.png" , "http://www.listrak.com/" ] ,
+  "lamail" : [ "imoffice.png" , "http://www.asi.co.jp/imoffice/" ] ,
   "lyris" : [ "lyris.png" , "http://www.lyris.com/" ] ,
   "lynx" : [ "lynx.png" , "http://lynx.isc.org/" ] ,
   "lucy" : [ "lucy.png" , "http://www.geniegate.com/other/lucy/" ] ,
+  "lms-" : [ "lms.png" , "http://www.lms.org.pl/" ] ,
 }
