@@ -2,18 +2,26 @@ dispMUA.arDispMUAAllocation["r"] =
 {
   "rtl digital newsletter system - www.rtl.be" : [ "rtl_be.png" , "http://www.rtlinfo.be/" ] ,
   "redemption mime converter" : [ "redemption.png" , "http://www.dimastr.com/redemption/" ] ,
-  "roving constant contact" : [ "roving_constant_contact.png" ] ,
+  "roving constant contact" : [ "roving_constant_contact.png" , "http://www.constantcontact.com/" ] ,
   "reportsuite mailer" : [ "samriddhi.png" , "http://www.sipl.net/html/reportsuiteoverview.htm" ] ,
+  "radica intimate" : [ "radica-intimate.png" , "http://www.radicasys.com/content/view/18/31/lang,en_HK/" ] ,
   "redmoonstudios" : [ "redmoonstudios_de.png" , "http://www.redmoonstudios.de/" ] ,
-  "roxen's email" : [ "roxen.png" ] ,
-  "rodriquezmail" : [ "rodriquezmail.png" , "" ] ,
+  "roxen's email" : [ "roxen.png" , "http://www.roxen.com/" ] ,
+  "rodriquezmail" : [ "rodriquezmail.png" ] ,
   "rapid-emailer" : [ "rapid-emailer.png" , "http://www.absolutefuturity.com/Rapid-Emailer.htm" ] ,
+  "rjsemail.cgi" : [ "perl.png" , "http://www.cpan.org/scripts/infoserv/WWW/rjsemail.cgi" ] ,
+  "realcommerce" : [ "realcommerce.png" , "http://www.realcommerce.co.il/" ] ,
+  "rasmas.info" : [ "rasmas_info.png" , "http://rasmas.info/" ] ,
   "rss2email" : [ "infogami.png" , "http://rss2email.infogami.com/" ] ,
+  "rozsylacz" : [ "rozsylacz.png" , "http://www.aionel.net/rozsyla.htm" ] ,
   "roundcube" : [ "roundcube.png" , "http://www.roundcube.net/" ] ,
   "reportbug" : [ "debian.png" , "http://www.debian.org/" ] ,
+  "readysoft" : [ "readysoft.png" , "http://www.readysoft.de/" ] ,
+  "readymail" : [ "readymail.png" , "http://www.readymail.de/" ] ,
   "ru.board" : [ "ru_board.png" ] ,
+  "risumail" : [ "risumail.png" , "http://www.risumail.jp/" ] ,
   "reservit" : [ "reservit.png" , "http://www.reservit.com/" ] ,
-  "rmrnews" : [ "rmr.png" ] ,
+  "rmrnews" : [ "rmr.png" , "http://www.rmrsoft.com/" ] ,
   "redmine" : [ "ruby.png" , "http://www.redmine.org/" ] ,
   "rscomm" : [ "rscomm.png" , "http://www.reinhardt-software.de/" ] ,
   "ramail" : [ "rambler_ru.png" , "http://www.rambler.ru/" ] ,
