@@ -1,13 +1,14 @@
-//  "webmail" : [ "1und1.png" , "http://www.1und1.de/" ] , // conflicts with others!
 dispMUA.arDispMUAAllocation["w"] =
 {
-  "www.talkaboutsportsnetwork.com" : [ "tasn.png" ] ,
+  "web business center - www.davinci-tec.de" : [ "davinci-tec.png" , "http://www.davinci-tec.de/" ] ,
+  "www.talkaboutsportsnetwork.com" : [ "tasn.png" , "http://www.talkaboutsportsnetwork.com/" ] ,
   "windows sharepoint services" : [ "ms_sharepoint.png" , "http://www.microsoft.com/" ] ,
   "webmail (1und1 webmailer)" : [ "1und1.png" , "http://www.1und1.de/" ] ,
   "www-mail (funpic portal)" : [ "funpic_de.png" , "http://www.funpic.de/" ] ,
   "www.20minutos.es mailer" : [ "20minutos_es.png" , "http://www.20minutos.es/" ] ,
   "woodstone servers alive" : [ "salive.png" ] ,
   "waste.uk.com mailsystem" : [ "waste.uk.com.png" , "http://www.waste.uk.com/" ] ,
+  "wavesetemailnotifier" : [ "sun.png" , "http://www.sun.com/software/waveset/" ] ,
   "wr-subscribe mailer" : [ "wr-scripts.png" , "http://wr.kovostok.ru/" ] ,
   "www.virtusales.com" : [ "virtusales_com.png" , "http://www.virtusales.com/" ] ,
   "www.mynewsgate.net" : [ "mynewsgate_net.png" , "http://www.mynewsgate.net/" ] ,
@@ -15,52 +16,71 @@ dispMUA.arDispMUAAllocation["w"] =
   "webmail.osnanet.de" : [ "osnatel_de.png" , "http://www.osnanet.de/" ] ,
   "www.bhsbinkert.de" : [ "bhsbinkert.png" , "http://www.bhsbinkert.de/" ] ,
   "woltlab community" : [ "wbb.png" , "http://community.woltlab.com/" ] ,
-  "webmail mirapoint" : [ "mirapoint.png" ] ,
+  "webmail mirapoint" : [ "mirapoint.png" , "http://www.mirapoint.de/" ] ,
   "webmail di libero" : [ "libero_it.png" , "http://liberomail.libero.it/" ] ,
-  "www.schworak.com" : [ "schworak.png" ] ,
-  "wordperfect mail" : [ "wordperfect.png" ] ,
+  "www.schworak.com" : [ "schworak.png" , "http://schworak.com/" ] ,
   "webmail-email.it" : [ "email_it.png" , "http://www.email.it/" ] ,
+  "webmail net site" : [ "netsite_webmail.png" , "http://webmail.netsite.com.br/" ] ,
   "web based pronto" : [ "web_based_pronto.png" ] ,
   "www.webspace.de" : [ "webspace_de.png" , "http://www.webspace.de/" ] ,
   "www.titulky.com" : [ "titulky_com.png" , "http://www.titulky.com/" ] ,
   "www.newsland.it" : [ "newsland_it.png" , "http://www.newsland.it/" ] ,
+  "workcentre m118" : [ "xerox_workcentre.png" , "http://www.office.xerox.com/" ] ,
   "webnews to mail" : [ "netwinsite.png" , "http://netwinsite.com/webnews/" ] ,
-  "webmail version" : [ "webmail.png" ] ,
+  "webmail version" : [ "webmail.png" , "http://www.unitedonline.net/" ] ,
   "web4u csendmail" : [ "web4u.png" , "http://www.web4u.cz/" ] ,
-  "web-based email" : [ "godaddy.png" ] ,
+  "web-based email" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
   "www.mailpro.pl" : [ "mailpro_pl.png" , "http://www.mailpro.pl/" ] ,
+  "www.allsync.de" : [ "allsync.png" , "http://www.allsync.de/" ] ,
   "windows eudora" : [ "eudora.png" , "http://www.eudora.com/" ] ,
-  "webmasterworld" : [ "webmasterworld.png" ] ,
+  "webmasterworld" : [ "webmasterworld.png" , "http://www.webmasterworld.com/" ] ,
   "webmail rol.ro" : [ "rol_ro.png" , "http://www.rol.ro/" ] ,
   "webedition cms" : [ "webedition.png" , "http://www.webedition.de/" ] ,
+  "w+r app server" : [ "gmx.png" , "http://www.wrgmbh.de/" ] ,
   "www.heycom.de" : [ "heycom_de.png" , "http://www.heycom.de/" ] ,
   "winehq mailer" : [ "winehq.png" , "http://www.winehq.org/" ] ,
+  "willco mailer" : [ "willco.png" , "http://www.willco.com/" ] ,
   "wg-gesucht.de" : [ "wg-gesucht_de.png" , "http://www.wg-gesucht.de/" ] ,
+  "wernis-portal" : [ "wernis-portal.png" , "http://www.wds66.com/" ] ,
   "webreport/400" : [ "webreport-400.png" , "http://www.kisco.com/webreport/" ] ,
+  "web help desk" : [ "webhelpdesk.png" , "http://www.webhelpdesk.com/" ] ,
+  "wdic-explorer" : [ "wdic_org.png" , "http://www.wdic.org/" ] ,
   "www.4free.pl" : [ "4free_pl.png" , "http://www.4free.pl/" ] ,
   "winnt's blat" : [ "blat.png" , "http://www.blat.net/" ] ,
+  "webmail/java" : [ "jwebmail.png" , "http://jwebmail.sourceforge.net/" ] ,
   "webalta-mail" : [ "webalta.png" , "http://www.webalta.ru/" ] ,
-  "worldclient" : [ "worldclient.png" ] ,
-  "winnt's msm" : [ "msm.png" ] ,
+  "worldclient" : [ "worldclient.png" , "http://mail.wordlex.de/" ] ,
+  "wordperfect" : [ "wordperfect.png" , "http://www.corel.com/servlet/Satellite/us/en/Product/1152105038635" ] ,
+  "winnt's msm" : [ "marval-msm.png" , "http://www.marval.co.uk/" ] ,
   "websurveyor" : [ "vovici.png" , "http://www.websurveyor.com/" ] ,
   "webroot.com" : [ "webroot_com.png" , "http://www.webroot.com/" ] ,
-  "webmail ulb" : [ "ulb.png" ] ,
+  "webmail ulb" : [ "webmail_ulb.png" , "http://webmail.ulb.ac.be/" ] ,
+  "web to date" : [ "web-to-date.png" , "http://www.webtodate.de/" ] ,
   "web de mail" : [ "web_de_mail.png" ] ,
   "wongmailer" : [ "wongmailer.png" , "http://www.mister-wong.com/" ] ,
+  "wmzona.com" : [ "wmzona_com.png" , "http://www.wmzona.com/" ] ,
   "whatcounts" : [ "whatcounts.png" ] ,
-  "wanderlust" : [ "wanderlust.png" ] ,
-  "west wind" : [ "westwind.png" ] ,
+  "web-casket" : [ "web-casket.png" , "http://www.web-casket.com/english/" ] ,
+  "wanderlust" : [ "wanderlust.png" , "http://www.gohome.org/wl/" ] ,
+  "wsmanager" : [ "wsmanager.png" , "http://www.webstar.ru/?content=technologies" ] ,
+  "westfalia" : [ "westfalia.png" , "http://wwww.westfalia.de/" ] ,
+  "west wind" : [ "westwind.png" , "http://www.west-wind.com/" ] ,
+  "webrymail" : [ "biglobe.png" , "http://webrymail.biglobe.ne.jp/" ] ,
   "webmail6." : [ "webmail_us.png" , "http://www.mailtrust.com/" ] ,
   "wdcollect" : [ "plesk.png" , "http://www.parallels.com/plesk/" ] ,
-  "windmail" : [ "windmail.png" ] ,
-  "wemail32" : [ "wemail.png" ] ,
+  "wmw.maam" : [ "webmasterware.png" , "http://www.webmasterware.net/" ] ,
+  "windmail" : [ "windmail.png" , "http://www.geocel.com/windmail/" ] ,
+  "wice crm" : [ "wice_crm.png" , "http://www.wice.de/" ] ,
+  "wemail32" : [ "wemail.png" , "http://www.ntes.co.jp/WeMail/" ] ,
   "web-news" : [ "web-news.png" , "http://web-news.sourceforge.net/" ] ,
-  "wamailer" : [ "wamailer.png" ] ,
-  "writely" : [ "writely.png" ] ,
-  "winbiff" : [ "winbiff.png" ] ,
+  "waxtrapp" : [ "waxtrapp.png" , "http://www.waxtrapp.com/" ] ,
+  "wamailer" : [ "wamailer.png" , "http://phpcodeur.net/wascripts/wamailer/" ] ,
+  "wswin32" : [ "wswin32.png" , "http://www.pc-wetterstation.de/" ] ,
+  "writely" : [ "writely.png" , "http://www.writely.com/" ] ,
+  "winbiff" : [ "winbiff.png" , "http://www.orangesoft.co.jp/modules/pukiwiki/?Winbiff" ] ,
   "webmin" : [ "webmin.png" , "http://www.webmin.com/" ] ,
   "webcit" : [ "webcit.png" , "http://www.citadel.org/" ] ,
-  "winvn" : [ "winvn.png" ] ,
+  "winvn" : [ "winvn.png" , "http://science.ksc.nasa.gov/software/winvn/" ] ,
   "whups" : [ "horde.png" , "http://www.horde.org/whups/" ] ,
   "wbb" : [ "wbb.png" , "http://www.woltlab.de/" ] ,
 }
