@@ -1,13 +1,15 @@
 dispMUA.arDispMUAAllocation["z"] =
 {
   "zercom online mailer" : [ "zercom.png" ] ,
-  "zope/securemailhost" : [ "zope_securemailhost.png" ] ,
+  "zope/securemailhost" : [ "zope.png" , "http://www.zope.com/" ] ,
   "zen cart mailer" : [ "zen-cart_com.png" , "http://www.zen-cart.com/" ] ,
-  "zoznam mailer" : [ "zoznam.png" ] ,
-  "zopemailboxer" : [ "zopemailboxer.png" ] ,
-  "zedat-webmail" : [ "zedat.png" ] ,
+  "zonepro france" : [ "zonepro.png" , "http://www.zonepro.fr/" ] ,
+  "zoznam mailer" : [ "zoznam.png" , "http://www.zoznam.sk/" ] ,
+  "zopemailboxer" : [ "zope.png" , "http://www.zope.com/" ] ,
+  "zedat-webmail" : [ "zedat.png" , "http://www.zedat.fu-berlin.de/" ] ,
+  "zatz zenpress" : [ "zatz-zenpress.png" , "http://zatzhq.zatz.com/zenpress" ] ,
   "zen mailer" : [ "zenmailer.png" , "http://www.zen-e-solutions.com/product4.htm" ] ,
-  "zuckmail" : [ "zuckmail.png" ] ,
+  "zuckmail" : [ "zuckmail.png" , "http://www.facebook.com/press/info.php?execbios" ] ,
   "z-mailer" : [ "z-mailer.png" , "http://www.z57.com/" ] ,
   "zmailer" : [ "zmailer.png" , "http://www.zmailer.org/" ] ,
   "zimbra" : [ "zimbra.png" , "http://www.zimbra.com/" ] ,
