@@ -7,28 +7,88 @@ var dispMUA =
   arDispMUAAllocation: {} ,
 }
 
+dispMUA.checktext = function()
+{
+  var selectedText = dispMUA.checktextGetSelectedText() ;
+  dispMUA.searchIcon ( selectedText ) ;
+}
+
+dispMUA.checktextPopup = function()
+{ 
+  var selectedText = dispMUA.checktextGetSelectedText() ;
+  var elem = document.getElementById ( "context_checktext" ) ;
+  elem.hidden = true ;
+       
+  if ( selectedText != "" )
+  {
+    if ( selectedText.length > 18 )
+    {
+      selectedText = selectedText.substr ( 0 , 14 ) + "..." ;
+    }
+
+    var menuText = "dispMUA: \"" + selectedText + "\"" ;
+    elem.setAttribute ( "label" , menuText ) ;
+    elem.hidden = false ;
+  }
+}
+
+dispMUA.checktextGetSelectedText = function()
+{ 
+  var node = document.popupNode ;
+  var selection = "" ;
+
+  if ( ( node instanceof HTMLTextAreaElement ) || ( node instanceof HTMLInputElement && node.type == "text" ) )
+  {
+    selection = node.value.substring ( node.selectionStart , node.selectionEnd ) ;
+  }
+  else
+  {
+    var focusedWindow = new XPCNativeWrapper ( document.commandDispatcher.focusedWindow , "document" , "getSelection();" ) ;
+    selection = focusedWindow.getSelection().toString() ;
+  }
+
+  selection = selection.replace ( /(^\s+)|(\s+$)/g , "" ) ;
+  return ( selection ) ;
+}
+
 dispMUA.StreamListener =
 {
   content: "" ,
+  found: false ,
   onDataAvailable: function ( request , context , inputStream , offset , count )
   {
     try
     {
       var sis = Components.classes["@mozilla.org/scriptableinputstream;1"].createInstance ( Components.interfaces.nsIScriptableInputStream ) ;
       sis.init ( inputStream ) ;
-      this.content += sis.read ( count ) ;
+
+      if ( ! this.found )
+      {
+        this.content += sis.read ( count ) ;
+        this.content = this.content.replace ( /\r/g , "" ) ;
+        var pos = this.content.indexOf ( "\n\n" ) ;
+
+        if ( pos > -1 )
+        {
+          // last header line must end with LF -> pos+1 !!!
+          this.content = this.content.substr ( 0 , pos + 1 ) ;
+          this.found = true ;
+        }
+      }
     }
     catch ( ex ) { }
   } ,
   onStartRequest: function ( request , context )
   {
     this.content = "" ;
+    this.found = false ;
   } ,
   onStopRequest: function ( aRequest , aContext , aStatusCode )
   {
     dispMUA.headers = Components.classes["@mozilla.org/messenger/mimeheaders;1"].createInstance ( Components.interfaces.nsIMimeHeaders ) ;
     dispMUA.headers.initialize ( this.content , this.content.length ) ;
-    dispMUA.searchIcon() ;
+    dispMUA.headerdata = this.content ;
+    dispMUA.searchIcon ( "" ) ;
   }
 } ;
 
@@ -61,11 +121,12 @@ dispMUA.getHeader = function ( key )
   return ( value ) ;
 }
 
-dispMUA.searchIcon = function()
+dispMUA.searchIcon = function ( strUserAgent )
 {
-  var strUserAgent = "" ;
-
-  var strUserAgent = dispMUA.getHeader ( "user-agent" ) ;
+  if ( ! strUserAgent )
+  {
+    strUserAgent = dispMUA.getHeader ( "user-agent" ) ;
+  }
 
   if ( ! strUserAgent )
   {
@@ -88,7 +149,7 @@ dispMUA.searchIcon = function()
     strExtra = "phpbug" ;
   }
 
-  strUserAgent = dispMUA.stripSurroundingQuotes ( strUserAgent ) ;
+  strUserAgent = strUserAgent.replace ( /(^\s+)|(\s+$)/g , "" ) ;
   dispMUA.Info["STRING"] = "" ;
   dispMUA.setInfo ( false , [] ) ;
 
@@ -114,6 +175,20 @@ dispMUA.searchIcon = function()
       }
     }
 
+    if ( !dispMUA.Info["FOUND"] )
+    {
+      var lower = strUserAgent.toLowerCase() ;
+
+      for ( var key in dispMUA.arDispMUAAllocation["fullmatch"] )
+      {
+        if ( lower == key )
+        {
+          dispMUA.setInfo ( true , dispMUA.arDispMUAAllocation["fullmatch"][key] ) ;
+          break ;
+        }
+      }
+    }
+
     if ( !dispMUA.Info["FOUND"] )
     {
       dispMUA.scan ( "presearch" , strUserAgent )
@@ -353,7 +428,8 @@ dispMUA.infopopup = function()
       dispMUA.Info["STRING"] ,
       "#990000" ,
       dispMUA.bundle.getString ( "dispMUA.NOTsupported" ) ,
-      dispMUA.Info["URL"]
+      dispMUA.Info["URL"] ,
+      dispMUA.headerdata
     ) ;
 
     if ( dispMUA.Info["FOUND"] )
@@ -364,7 +440,7 @@ dispMUA.infopopup = function()
 
     window.openDialog ( "chrome://dispmua/content/feedback.xul" ,
     "feedback" , "chrome=yes,centerscreen" ,
-    param[0] , param[1] , param[2] , param[3] , param[4] ) ;
+    param[0] , param[1] , param[2] , param[3] , param[4] , param[5] ) ;
   }
 }
 
@@ -382,6 +458,9 @@ dispMUA.init_overlay = function()
   listener.onEndHeaders = dispMUA.loadHeaderData ;
   gMessageListeners.push ( listener ) ;
 
+  var elem = document.getElementById ( "messagePaneContext" ) ;
+  elem.addEventListener ( "popupshowing" , dispMUA.checktextPopup , false ) ;
+
   dispMUA.loadMUAOverlayFile() ;
 }
 
